package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````,`MP`!````E",```````!``````````-"A````
M`````````$``.``(`$``&@`9``8````%````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````#26````````-)8`````````
M``$```````$````&````()L````````@FP$``````"";`0``````F`4`````
M``#(%0```````````0```````@````8````XFP```````#B;`0``````.)L!
M```````@`@```````"`"````````"``````````$````!````!P"````````
M'`(````````<`@```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````@FP```````"";`0``````()L!``````#@!```````
M`.`$`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`"O;U0\!4:ZXP+Y?_K^2%2QAKIOP1````4`````0````(````(1`0``7`
M!(0H`A`!@(9`@((I``0)(`2)B*`81;H$`@A0````40```%4```!:````6P``
M`&(```!C````9````&8```!G`````````&D```!J````:P```&T`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M`````````````````````````````P`+`#@=````````````````````````
M`P`3`#";`0````````````````#$`@``$@````````````````````````!(
M`P``$@````````````````````````"4`@``$@``````````````````````
M``";`@``$@`````````````````````````Z`P``$@``````````````````
M```````[`@``$@`````````````````````````1````(```````````````
M``````````#L`@``$@`````````````````````````$`P``$@``````````
M```````````````K`P``(@````````````````````````#]`@``$@``````
M``````````````````#D`@``$@````````````````````````#(````$@``
M``````````````````````#V`@``$0````````````````````````"7`0``
M$@`````````````````````````I`@``$@````````````````````````!(
M`@``$@````````````````````````"8````$@``````````````````````
M```@`0``$@`````````````````````````-`P``$@``````````````````
M``````"-`@``$@````````````````````````"^`0``$@``````````````
M```````````5`0``$0````````````````````````#+`@``$@``````````
M``````````````![`0``$@````````````````````````#W````$0``````
M``````````````````!)`0``$@````````````````````````!``@``$@``
M``````````````````````!>`P``$@````````````````````````"B`@``
M$@````````````````````````#6````$@````````````````````````#%
M`0``$@`````````````````````````2`@``$@``````````````````````
M``"R`0``$@````````````````````````#@`0``$@``````````````````
M``````!X`@``$@````````````````````````!1`@``$@``````````````
M``````````!:`@``$@````````````````````````#T`0``$@``````````
M``````````````!7`0``$@`````````````````````````M````(```````
M``````````````````"0`P``$0````````````````````````!Q`P``(0``
M``````````````````````"``@``$@````````````````````````!0`P``
M$@````````````````````````!X````$@````````````````````````"V
M`@``$@````````````````````````!7`P``$@``````````````````````
M```<!```$@````````````````````````"P`@``$@``````````````````
M``````"G````$@````````````````````````"S````$@``````````````
M``````````!P`0``$@````````````````````````#9`@``$@``````````
M```````````````V`0``$@`````````````````````````E`0``$@``````
M``````````````````!J````$@`````````````````````````A`P``$@``
M```````````````````````J`0``$@````````````````````````"G`0``
M$@`````````````````````````$`0``$@`````````````````````````:
M`P``$@````````````````````````")`0``$@``````````````````````
M``"'````$@`````````````````````````:`@``$@``````````````````
M``````"&`@``$@````````````````````````!P`P``$0``````````````
M``````````!R`P``$0`````````````````````````\````(```````````
M``````````````#Z`0``$@````````````````````````#H````$@``````
M``````````````````!G`0``$@````````````````````````"I`@``$@``
M``````````````````````!0````(``````````````````````````!`@``
M$@````````````````````````!K`@``$@````````````````````````!R
M`@``$@````````````````````````#1`P``$``7`.BP`0``````````````
M```E!```$@`-`"!3````````@`````````#S`P``$@`.`#Q4````````````
M``````!*!```$@`-`-!%````````M`D```````!K`P``$@`-`'`A````````
M)`(```````#Y`P``$@`-`(`^````````!`````````#"`P``$``7`+B@`0``
M``````````````"K!```$@`-`(@^````````]`$```````"E!```$@`+`#@=
M``````````````````#8!```$@`-`(A/````````E`,```````"V`P``$``7
M`+B@`0`````````````````Q!```$@`-`(!`````````(`````````!7!```
M$0`/`%!4````````!`````````#D`P``$``7`.BP`0````````````````#<
M`P``$``7`.BP`0````````````````"C!```$@`-``@]````````.```````
M``"X!```$@`-`'A$````````5`$```````#*!```$@`-`+A#````````F```
M``````"B`P``$``6``"@`0`````````````````^!```$@`-`*!`````````
M.`$```````"O`P``$``6`+B@`0````````````````",!```$0`6`+"@`0``
M````"`````````#I`P``$@`-`#A4````````!`````````!\!```$@`-`,!3
M````````>`````````"H`P``$@`-`)0C``````````````````"D`P``(``6
M``"@`0`````````````````*!```$@`-`%!$````````*`````````#0`P``
M$``7`.BP`0````````````````!F!```$@`-`)@]````````Y`````````"6
M!```$@`-`-A!````````X`$`````````;&EB<&5R;"YS;RXU+C(R`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G
M:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E
M<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`
M4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L
M7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?
M<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R
M;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`&QI8G!T:')E
M860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R
M<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`7U]R96=I<W1E
M<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A
M8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR
M`&=E='!I9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F
M<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P
M96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC
M<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I
M;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA
M:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%A<F-H-C0N<V\N,0!?7W-T86-K7V-H
M:U]G=6%R9`!?7V1A=&%?<W1A<G0`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S
M7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C<W5?
M9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?
M;6MT;7!D:7(`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS7VEN
M:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,3<```````````(`
M`@`"``(``@`"`````@`"``(``@`"`````@````(``@```````@`"``(````"
M``````````(``@`"```````#`````P`"``(``@`#```````$``(``@`"````
M`@`"``(``@`````````"`````@````(``````````@```````P`"``(``@``
M``,```````(````#``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0````$``0!Z`P``$```
M`"````"7D98&```$`.X$`````````0`!`-`!```0````(````)>1E@8```,`
M[@0````````!``$`'P(``!``````````EY&6!@```@#N!````````"";`0``
M`````P0```````"@)````````"B;`0```````P0```````!8)````````'B?
M`0```````P0````````X5````````,"?`0```````P0````````(H`$`````
M`,B?`0```````P0```````#`4P```````-B?`0```````P0```````!P(0``
M``````B@`0```````P0````````(H`$``````!B@`0```````P0```````!@
M6````````""@`0```````P0```````!P6````````"B@`0```````P0`````
M``!X6````````#"@`0```````P0```````"`6````````#B@`0```````P0`
M``````"(6````````$"@`0```````P0```````"@6````````%"@`0``````
M`P0```````!86````````%B@`0```````P0```````#X5````````&B@`0``
M`````P0````````(5@```````'"@`0```````P0````````X6````````'B@
M`0```````P0```````!`6````````("@`0```````P0```````!(6```````
M`(B@`0```````P0```````!06````````)B@`0```````P0````````@6```
M`````*"@`0```````P0````````H6````````+"@`0```````P0```````"P
M6````````("?`0```````00```D``````````````(B?`0```````00```P`
M`````````````)"?`0```````00``!```````````````)B?`0```````00`
M`!$``````````````*"?`0```````00``!D``````````````*B?`0``````
M`00``!P``````````````+"?`0```````00``"L``````````````+B?`0``
M`````00``"P``````````````-"?`0```````00``#D``````````````."?
M`0```````00``$(``````````````.B?`0```````00``$8`````````````
M`/"?`0```````00``$<``````````````/B?`0```````00``$P`````````
M`````'"=`0```````@0```,``````````````'B=`0```````@0```0`````
M`````````("=`0```````@0```4``````````````(B=`0```````@0```8`
M`````````````)"=`0```````@0```<``````````````)B=`0```````@0`
M``@``````````````*"=`0```````@0```H``````````````*B=`0``````
M`@0```L``````````````+"=`0```````@0```P``````````````+B=`0``
M`````@0```T``````````````,"=`0```````@0```X``````````````,B=
M`0```````@0```\``````````````-"=`0```````@0``!(`````````````
M`-B=`0```````@0``!,``````````````."=`0```````@0``!0`````````
M`````.B=`0```````@0``!4``````````````/"=`0```````@0``!8`````
M`````````/B=`0```````@0``!<```````````````">`0```````@0``!@`
M``````````````B>`0```````@0``!H``````````````!">`0```````@0`
M`!L``````````````!B>`0```````@0``!T``````````````"">`0``````
M`@0``!X``````````````"B>`0```````@0``!\``````````````#">`0``
M`````@0``"```````````````#B>`0```````@0``"$``````````````$">
M`0```````@0``"(``````````````$B>`0```````@0``",`````````````
M`%">`0```````@0``"0``````````````%B>`0```````@0``"4`````````
M`````&">`0```````@0``"8``````````````&B>`0```````@0``"<`````
M`````````'">`0```````@0``"@``````````````'B>`0```````@0``"D`
M`````````````(">`0```````@0``"H``````````````(B>`0```````@0`
M`"L``````````````)">`0```````@0``"X``````````````)B>`0``````
M`@0``"\``````````````*">`0```````@0``#```````````````*B>`0``
M`````@0``#$``````````````+">`0```````@0``#(``````````````+B>
M`0```````@0``#,``````````````,">`0```````@0``#0`````````````
M`,B>`0```````@0``#4``````````````-">`0```````@0``#8`````````
M`````-B>`0```````@0``#<``````````````.">`0```````@0``#@`````
M`````````.B>`0```````@0``#H``````````````/">`0```````@0``#L`
M`````````````/B>`0```````@0``#P```````````````"?`0```````@0`
M`#T```````````````B?`0```````@0``#X``````````````!"?`0``````
M`@0``#\``````````````!B?`0```````@0``$```````````````""?`0``
M`````@0``$$``````````````"B?`0```````@0``$,``````````````#"?
M`0```````@0``$0``````````````#B?`0```````@0``$@`````````````
M`$"?`0```````@0``$D``````````````$B?`0```````@0``$H`````````
M`````%"?`0```````@0``$L``````````````%B?`0```````@0``$T`````
M`````````&"?`0```````@0``$X``````````````&B?`0```````@0``$\`
M`````````````/U[OZG]`P"1HP$`E/U[P:C``U_6`````/![OZG0``"0$;9&
M^1"B-9$@`A_6'R`#U1\@`]4?(`/5T```D!&Z1OD0PC61(`(?UM```)`1OD;Y
M$.(UD2`"'];0``"0$<)&^1`"-I$@`A_6T```D!'&1OD0(C:1(`(?UM```)`1
MRD;Y$$(VD2`"'];0``"0$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM``
M`)`1UD;Y$*(VD2`"'];0``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?
MUM```)`1XD;Y$`(WD2`"'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1
M(`(?UM```)`1[D;Y$&(WD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0
MHC>1(`(?UM```)`1^D;Y$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"
M1_D0`CB1(`(?UM```)`1!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```
MD!$.1_D08CB1(`(?UM```)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6
MT```D!$:1_D0PCB1(`(?UM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@
M`A_6T```D!$F1_D0(CF1(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B
M.9$@`A_6T```D!$R1_D0@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'
M^1#".9$@`A_6T```D!$^1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0
M$49'^1`B.I$@`A_6T```D!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0
M``"0$5)'^1"".I$@`A_6T```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"
M']:P``#P$5Y'^1#B.I$@`A_6L```\!%B1_D0`CN1(`(?UK```/`19D?Y$"([
MD2`"']:P``#P$6I'^1!".Y$@`A_6L```\!%N1_D08CN1(`(?UK```/`1<D?Y
M$(([D2`"']:P``#P$79'^1"B.Y$@`A_6L```\!%Z1_D0PCN1(`(?UK```/`1
M?D?Y$.([D2`"']:P``#P$8)'^1`"/)$@`A_6L```\!&&1_D0(CR1(`(?UK``
M`/`1BD?Y$$(\D2`"']:P``#P$8Y'^1!B/)$@`A_6L```\!&21_D0@CR1(`(?
MUK```/`1ED?Y$*(\D2`"']:P``#P$9I'^1#"/)$@`A_6L```\!&>1_D0XCR1
M(`(?UK```/`1HD?Y$`(]D2`"']:P``#P$:9'^1`B/9$@`A_6L```\!&J1_D0
M0CV1(`(?UK```/`1KD?Y$&(]D2`"']:P``#P$;)'^1""/9$@`A_6L```\!&V
M1_D0HCV1(`(?UOU[N:G]`P"1\U,!J;0``/#U6P*ITP``L/<;`/FU``#P@]Y'
M^:*'!*FA0P&1H%\`N:(C`9&@<P&19`!`^:0W`/D$`(#2A___EZ(``/"@``#P
M0NA'^0#P1_GA`P*J=0P`E*```/``U$?Y``!`.6`!`#5,__^78@('D4``$O@`
M#0"TM0``\!?__Y>@TD?Y``!`N5#__Y<?5"0YM=)'^:`"0+E,__^7`4A4.2$`
M'S(!2!0YH`)`N4?__Y<!2%0Y(0``,@%(%#F@7T"Y`!0`$0!\?9,\__^7I"M`
M^<8``)!A`@>1HE]`N04``/`#``#PQUA`^8@`@%*&`$#YI4`@D6-@()%?!`!Q
M!A0`J0<,`:DH@!"X(``1^.T&`%2$(`"10Q``$:$`@%+G`("2Y<PABX:$0/@A
M!``1/P`#:P9H)?AA__]4=@('D07,(XL!``"PXP,`JD(,`!$A`#61P`)2^`0`
M@-*_@!_X<___E_4#`"H@`P`T=@('D;>3`9'``E+X\?[_EP```/#A`Q>J`.`5
MD<T$`)2``@"T<P('D6`"4OC5_O^76/__EY3>1_G@`Q4JHC=`^8$"0/E!``'*
M`0,`M?-30:GU6T*I]QM`^?U[QZC``U_6P`)2^'?__Y?U`P`JY?__%\""4?B@
M``"T\@L`E.K__Q=#``@+T___%P```/#A`Q>J```4D:\$`)3`@A'X0/S_M.@+
M`)3@__\7^O[_ER``@%*,_O^7'0"`TAX`@-+E`P"JX0-`^>(C`)'F`P"1H```
M\`#L1_FC``#P8^1'^:0``/"$O$?YQ_[_E_K^_Y>@``#P`-A'^4```+3R_O\7
MP`-?UL$``)#```"0(>`"D0#@`I$A'`"1(0``RS\X`/&I``!4H0``\"'`1_E!
M``"T(``?UL`#7]8?(`/5P0``D,```)`AX`*1`.`"D2$``,LA_$.3(?Q!BR'\
M09/!``"TH@``\$+\1_EB``"T0``?UA\@`]7``U_6'R`#U?U[OJG]`P"1\PL`
M^=,``)!@XD(Y0`$`-:```/``Q$?Y@```M,```)``!$#Y6_[_E];__Y<@`(!2
M8.(".?,+0/G]>\*HP`-?UJ```/``P"R1`0!`^6$``+7:__\7'R`#U:$``/`A
M^$?Y@?__M/U[OZG]`P"1(``_UOU[P:C1__\7_T,*T:@``/`%X`"1">`!D?U[
MOZG]`P"1`=U'^:)C`)%'(`"1(P!`^:-/`?D#`(#2HP!`N:&$0/AC",!:XX`?
M^+\`">LD_&#3)OQHTX/<>-/&''B2A!QHTV,<<)+!X$&J@P`#JF$``:KA!`'X
M(?[_5$8`")%#`$#Y0B``D44$0/E!'$#Y1#!`^:,``\I?``;K@0`!RF$``<HC
M_%_3800!JB%\0))!/`#Y8?[_5`,<0*DA,X_2!!A!J>``9Y[!`&>>9?Q;TX(`
M9YX*$$#YH@]`^:44`ZI!4*OR0@$"BT`<82YA`&>>"0!FGB5!)8NB``*+Y?Q"
MTT(``8NE>`>J2WQ`DJ5\0)*@`&>>K@`KBJ430/EI_5O3Q0`%BRD5"ZH!'&(N
M+`!FGHP!`8N%`06+;/Q"TXQY`ZJI0"F+C'U`DBU]0))"``R*I1=`^<(!`JJ/
M`2V*A0`%BT(``8M"``6+I?U;TZ44#:I%0"6+8OU"TT)X"ZJK?$"23GQ`DJ(;
M0/DI`0Z*T`$KBND!":H/`&:>0@`!BRD!#XLI`0*+8OU;TT(4"ZHB02*+J?U"
MTREY#:JM'T#Y+WU`DDE\0)*E``^*K0$!BP4"!:KP`2F*I0`,BRS]6].E``V+
MC!4)JJ5`+(ML_4+3BWD+JFU]0)*K?$"23``-BJ(C0/D,`@RJL`$KBHP!#HM"
M``&+@@$"BVS]6].,%0NJ0D`LBRS]0M.)>0FJ+GU`DDE\0)*E``Z*!0(%JM`!
M*8JE``^+K+]$J8P!`8OO`0&+I0`,BRS]6].,%0FJI4`LBVS]0M.+>0NJ;'U`
MDJM\0))"``R*`@("JI`!*XI"``V+;?U;TT(`#XNO+T#YK14+JN\!`8M"0"V+
M+?U"TZEY":HM?4"227Q`DJ4`#8H%`@6JL`$IBJ4`#HLN_5O3I0`/BZ\S0/G.
M%0FJ[P$!BZ5`+HMN_4+3RWD+JFY]0)*K?$"20@`.B@("`JK0`2N*0@`,BVS]
M6]-"``^+KS=`^8P5"ZKO`0&+0D`LBRS]0M.)>0FJ+'U`DDE\0)*E``R*!0(%
MJI`!*8JE``V++?U;TZ4`#XNO.T#YK14)JN\!`8NE0"V+;?U"TZMY"ZIM?4"2
MJWQ`DD(`#8H"`@*JL`$KBD(`#HMN_5O30@`/BZ\_0/G.%0NJ[P$!BT)`+HLN
M_4+3R7D)JBY]0)))?$"2I0`.B@4"!:K0`2F*I0`,BRS]6].E``^+KT-`^8P5
M":KO`0&+I4`LBVS]0M.+>0NJ;'U`DJM\0))"``R*`@("JI`!*XI"``V+;?U;
MTT(`#XNO1T#YK14+JN\!`8M"0"V++?U"TZEY":HM?4"227Q`DJ4`#8H%`@6J
MI0`.BR[]6].E``^+SA4)JJ5`+HMN_4+3L7Q`DLMY"ZJN2T#Y;WU`DJL!*8I"
M``^*S@$!BV(!`JHK_EO30@`,BVL5$:I"``Z+0D`KBRO]0M-0?$"2:7D)JBY]
M0)*I3T#YK``.BN4!,8JL``RJ*P$!BR7^0M.)`0V+*0$+BPO^6].E>!&JK7Q`
MDFL5$*I,``V*P@$PBBM!*XM,``RJ97U`DHP!#XNI/TJIHOQ;TRD!`8M"%`6J
MB0$)B^\!`8LI02*+`OY"TRQ]0))">!"JL`$EBD)\0))K`0**"P(+JK!;0/EK
M`0Z+COU;TVL!#XL!`@&+SA4,JE``+(IN02Z+J_Q"TV5Y!:K+?4"2KWQ`DBD!
M#XH)`@FJ*0$-BR$!`8MI_5O3*14+JBE`*8N!_4+3,'U`DBQX#*HA=)W2I0`,
MRB';K?*E``Y*H@`"BZ6W2ZFE``&+K0$!BT4`!8L"_EO30A00JJ)`(HME_4+3
M3GQ`DJMX"ZJ%`0O*I0`)2@G^0M.E``^+K0`-B\7]6],I>1"J;P$)RJ44#JKB
M`0)*I4$EBZU\0)),0"R+HF=`^4(``8N,`0*+HOU;TT(4#:J"02*+S/U"TXYY
M#JI,?$"2+P$.RN4!!4JK0"N+I6M`^:4``8MK`06+A?U;TZ44#*IE026+J_U"
MTVUY#:JK?$"2SP$-RN(!`DI)0"F+HF]`^4(``8LI`0*+8OU;TT(4"ZHB02*+
MB?U"TRQY#*I)?$"2KP$,RN4!!4JN0"Z+I7-`^:4``8O.`06+)?U;TZ44":K%
M026+;OU"T\MY"ZJN?$"2CP$+RN(!`DI-0"V+HG=`^4(``8NM`0*+POU;TT(4
M#JJB02*++?U"TZEY":I-?$"2;P$)RN4!!4JL0"R+I7M`^:4``8N,`06+I?U;
MTZ44#:J%026+S/U"TXYY#JJL?$"2+P$.RN(!`DI+0"N+HG]`^4(``8MK`0*+
M@OU;TT(4#*IB02*+J_U"TVUY#:I+?$"2SP$-RN4!!4JI0"F+I8-`^:4``8LI
M`06+9?U;TZ44"ZHE026+B?U"TRQY#*JI?$"2KP$,RN(!`DI.0"Z+HH=`^4(`
M`8O.`0*+(OU;TT(4":K"02*+;OU"T\MY"ZI.?$"2CP$+RN4!!4JM0"V+I8M`
M^:4``8NM`06+Q?U;TZ44#JJE026++?U"TZEY":JM?$"2;P$)RN(!`DI,0"R+
MHH]`^4(``8N,`0*+HOU;TT(4#:J"02*+S/U"TXYY#JI,?$"2+P$.RN4!!4JK
M0"N+I9-`^:4``8MK`06+A?U;TZ44#*IE026+J_U"TVUY#:JK?$"2SP$-RN(!
M`DI)0"F+HI=`^4(``8LI`0*+8OU;TT(4"ZHB02*+B?U"TRQY#*I)?$"2KP$,
MRN4!!4JN0"Z+I9M`^:4``8O.`06+)?U;TZ44":K%026+;OU"T\MY"ZJN?$"2
MCP$+RN(!`DI-0"V+HI]`^4(``8NM`0*+POU;TT(4#JJB02*++?U"TZEY":I-
M?$"2;P$)RN4!!4JO_4+3K$`LBZ6C0/GO>0VJI0`!BXP!!8NE_5O3I10-JH5!
M)8O,_4+3L'Q`DHYY#JHL`0[*@@$"2DQ`*XO+`0_*90$%2J5`*8NBIU2I0@`!
MBR$!`8N,`0*+`OY;TZ$``8L%_D+30A00JJ5X$*J"02*+ZP$%BDQ\0)*)_5O3
M*14,JC)`*8OA`06J(@`"BE!^0))"``LJJ:]`^8&;E])AX['R2T`NBRD!`8MI
M`0F+"_Y;TVL5$*HQ02N+B?U"TRU^0)*KLT#Y+GD,JJD`#JJL``Z**0$2BFL!
M`8LI`0PJ(D$OBZG]6]-"``N+*14-JD]`*8L"_D+30G@0JO!]0)++`0*JR0$"
MBFL!$8IK`0DJ94$EBZNW0/EK`0&+I0`+BPO^6]-K%1"JL4`KBZ7]0M,L?D"2
MJ[M`^:UX#:I%``VJ:P$!BZ4`#XI/``V*I0`/*JE`+HN%_5O3*0$+BZ44#*HO
M026+"?Y"TREY$*KP?4"2JP$)JJ4!"8IK`1&*:P$%*F)!(HNKOT#Y:P$!BT(`
M"XL+_EO3:Q40JE%`*XN"_4+3+GY`DJO#0/E,>`RJ(@$,JFL!`8M"``^*+P$,
MBD(`#RI%0"V+POU;TZ4`"XM"%`ZJKT`BBP7^0M.E>!"J\'U`DHL!!:J"`06*
M:P$1BFL!`BII02F+J\=`^6L!`8LI`0N+"_Y;TVL5$*HQ02N+R?U"TRU^0)*K
MRT#Y+GD.JJD`#JIK`0&+*0$/BJ\`#HHI`0\J(D$LBZG]6]-"``N+*14-JD]`
M*8L"_D+30G@0JO!]0)++`0*JR0$"BFL!$8IK`0DJ94$EBZO/0/EK`0&+I0`+
MBPO^6]-K%1"JL4`KBZ7]0M,L?D"2J]-`^:UX#:I%``VJ:P$!BZ4`#XI/``V*
MI0`/*JE`+HN%_5O3*0$+BZ44#*HO026+"?Y"TREY$*KP?4"2JP$)JJ4!"8IK
M`1&*:P$%*F)!(HNKUT#Y:P$!BT(`"XL+_EO3:Q40JE%`*XN"_4+3+GY`DJO;
M0/E,>`RJ(@$,JFL!`8M"``^*+P$,BD(`#RI%0"V+POU;TZ4`"XM"%`ZJKT`B
MBP7^0M.E>!"J\'U`DHL!!:J"`06*:P$1BFL!`BII02F+J]]`^6L!`8LI`0N+
M"_Y;TVL5$*HQ02N+R?U"TRU^0)*KXT#Y+GD.JJD`#JIK`0&+*0$/BJ\`#HHI
M`0\J(D$LBZG]6]-"``N+*14-JD]`*8L"_D+30G@0JO!]0)++`0*JR0$"BFL!
M$8IK`0DJ94$EBZOG0/EK`0&+I0`+BPO^6]-K%1"JL4`KBZ7]0M,L?D"2J^M`
M^:UX#:I%``VJ:P$!BZ4`#XI/``V*I0`/*JE`+HN%_5O3*0$+BZ44#*HN026+
M"?Y"TREY$*K0?4"2JP$)JJ4!"8IK`1&*:P$%*F)!(HNK[T#Y:P$!BT(`"XL+
M_EO3:Q40JE%`*XN"_4+3+WY`DJOS0/E,>`RJ(@$,JFL!`8M.``Z*(@$,BLX!
M`BK%02V+[?U;TZ4`"XNM%0^JHD`MBP7^0M-.?$"2I7@0JHL!!:J-`06*:P$1
MBFL!#2II02F+J_=`^6L!`8LI`0N+R_U;TVL5#JHK02N+Z?U"TVU]0)(O>0^J
MJ0`/JB(!`HJI``^*0@`)*JG[0/D(W4?Y0D`LBR$!`8M!``&+HOU;TT(4#:HB
M0"*+P?U"TTE\0)(N>`ZJX0$.RB$`"TJK_T#Y)4`EB\$ZF-)!3+GR:P$!BZL`
M"XLE_5O3I10)JF5!)8NK_4+3K'Q`DFUY#:K+`0W*8@$"2JL#0?E"0"^+:P$!
MBTL`"XN"_5O30A0,JF)!(HLK_4+3:7D)JDM\0)*O`0G*Y0$%2JY`+HNE!T'Y
MI0`!B\X!!8ME_5O3I10+JL5!)8N._4+3S'D,JJY\0)(O`0S*X@$"2DU`+8NB
M"T'Y0@`!BZT!`HO"_5O30A0.JJ)!(HMM_4+3JWD+JDU\0)*/`0O*Y0$%2JE`
M*8NE#T'YI0`!BRD!!8NE_5O3I10-JB5!)8O)_4+3+GD.JJE\0))O`0[*X@$"
M2DQ`+(NB$T'Y0@`!BXP!`HLB_5O30A0)JH)!(HNL_4+3C7D-JDQ\0)+/`0W*
MY0$%2JM`*XNE%T'YI0`!BVL!!8N%_5O3I10,JF5!)8LK_4+3:7D)JJM\0)*O
M`0G*X@$"2DY`+HNB&T'Y0@`!B\X!`HMB_5O30A0+JL)!(HN._4+3S'D,JDY\
M0)(O`0S*Y0$%2JU`+8NE'T'YI0`!BZT!!8O%_5O3I10.JJ5!)8MM_4+3JWD+
MJJU\0)*/`0O*X@$"2DE`*8NB(T'Y0@`!BRD!`HNB_5O30A0-JB)!(HO)_4+3
M+GD.JDE\0))O`0[*Y0$%2JQ`+(NE)T'YI0`!BXP!!8LE_5O3I10)JH5!)8NL
M_4+3C7D-JJQ\0)+/`0W*X@$"2DM`*XNB*T'Y0@`!BVL!`HN"_5O30A0,JF)!
M(HLK_4+3:7D)JDM\0)*O`0G*Y0$%2JY`+HNE+T'YI0`!B\X!!8ME_5O3I10+
MJL5!)8N._4+3S'D,JJY\0)(O`0S*X@$"2DU`+8NB,T'Y0@`!BZT!`HO"_5O3
M0A0.JJ)!(HMM_4+3JWD+JDU\0)*/`0O*Y0$%2J_]0M.I0"F+I3=!^>]Y#:JE
M``&+)0$%BZG]6],I%0VJJ4`IB\7]0M,P?4"2KG@.JF4!#LJB``)*I3M!^4)`
M+(NE``&+10`%BP+^6]/,`0_*0A00JHD!"4JL/T'YHD`BBRE!*XM%?$"2C`$!
MBRP!#(NI_%O3*14%JHE!*8L,_D+3+7U`DHQY$*KK`0S*8@$"2JM#0?E"0"Z+
M:P$!BTL`"XNB_$+3KOU;TT5X!:J"`07*SA4-JD(`"4JJ``H+:T$NBPH0`/E)
M0"^+:GU`DJ)'0?E"``&+(@$"BTG]6],I%0JJ(@$""^<``@L'!`#YI_U"T^=X
M#:JE``?*Y@`&"Z4`"TJG2T'Y!@P`^4;\6].E0"R+X0`!B\(4`JJA``&+00`!
M"R$``PL!``#YH4]!^0(!0/DB``+*0?U"TR%X"JHD``0+!`@`^8(``+7]>\&H
M_T,*D<`#7]91^O^70`<`M*(``-#]>[RI_0,`D4+T1_GS4P&I]5L"J?=C`ZE8
M`$#Y&`,`M`,`0#FB!X!2%`"`4G\``'%D$$)ZXP>?&@,#`#43`T#Y\P$`M/<#
M`:KV`P"JE'Y`D_4#&*K@`Q.JX@,4JN$#%JH.^O^7@```-6!J=#@?]`!Q0`(`
M5+..0/CS_O^U``"`TO-30:GU6T*I]V-#J?U[Q*C``U_6'R`#U?0#`*J#'D`X
M?P``<6000GJA__]4E`(`2^/__Q<?(`/5H@(8RX`&`)%@`@"+0OQ#D^("`+GS
M4T&I]5M"J?=C0ZG]>\2HP`-?U@``@-+``U_6_7N\J?T#`)'U6P*IM@``T/-3
M`:FS``#0]0,`JK33`)'`WD?Y<_9'^0$`0/FA'P#Y`0"`TN$#%*K@`Q6JM?__
ME^`!`+2C-X"Y8@)`^4`,`XL!!$#Y07@C^.'^_[0`(`"1`01`^0$``/FA__^U
MX0,4JN`#%:JG__^78/[_M=;>1_FA'T#YP`)`^2```,J@``"U\U-!J?5;0JG]
M>\2HP`-?UNSY_Y<?(`/5_7NYJ?T#`)'S4P&I\P,!JO5;`JFU``#0]V,#J?0#
M`*KY:P2I^RL`^:#>1_DA`$`Y/_0`<0$`0/FA-P#Y`0"`TG,6DYK@`Q.J9/G_
ME_8#`*JADP&1X`,4JH3__Y=@"`"T]P,`JEWY_Y??`@#K*0<`5+=G@+FY``#0
M]_)]TX`"0#FB!X!2'P``<0000GI`#`!4X0,4JB`<0#@?``!Q!!!">J'__U0A
M`!3+(7Q`DSCW1_G`"@"1```!BQ8#0/F#^?^7P&HW^"`+`+2C9X"Y@`8`D0(#
M0/F!`D`Y/_0`<4)X8_@D&$!Z00``.>```%2C!X!2`11`.#\``'%!'``X)!!#
M>H'__U2@!X!2000`D4```#E@%D`X(!0`.,#__S4``(!2M=Y'^:(W0/FA`D#Y
M00`!R@$(`+7S4T&I]5M"J?=C0ZGY:T2I^RM`^?U[QZC``U_6``"`TF%J8#CA
M:B`X``0`D:'__S7N__\7N0``T"#W1_D7`$#YX`)`^2`%`+3A`Q>J``"`4@(`
M`!3@`Q@J(HQ`^!@$`!&B__^U``P`$0!\?9.A``#P(L!`N<(!`#3A`P"JX`,7
MJG7Y_Y<A]T?Y(```^4`#`+0;?T"3^@,`JG?S?=-[!P"17WL[^+AG`+FH__\7
M(@"`4B+``+DX^?^7^@,`JL`!`+0;?T"3X0,7JG?S?=/B`Q>J[?C_ER#W1_D:
M``#Y\/__%P$`@-*E__\7``*`TA@`@%+?__\7``"`$KW__Q=>^?^7'R`#U?U[
MLJG]`P"1\U,!J;0``-#U6P*I]V,#J8'>1_GY(P#Y(@!`^:)O`/D"`(#2@```
MM`$`0#GU`P"J@0$`-93>1_FA;T#Y@`)`^2```,H`"0"U\U-!J?5;0JGW8T.I
M^2-`^?U[SJC``U_6ZOC_E_8#`*I@_O^T&```T+EC`9$80Q*1X`,6JG_Y_Y?E
M`P"JX`0`M*!,0#D?N`!Q0`4`5.`#%:JS3`"1O_C_E_<#`*K@`Q.JO/C_EP``
M%PL`"``1`'Q`D_3X_Y?W`P"JY0,3JN0#%:KC`QBJ`@"`DB$`@%*U^/^7X@,9
MJN$#%ZH``(!2N?C_EQ\$`#&@``!4H&M`N0`,%!(?$$!QX`(`5.`#%ZJ1^?^7
MX`,7JE/Y_Y?@`Q:J6?G_E^4#`*I@^_^UX`,6J@WY_Y?@`Q6J-_G_E\'__Q<?
M(`/5H%!`.>#Y_S0?N`!Q@?K_5*!40#E@^?\TT?__%Q\@`]7@`Q>JI___E^K_
M_Q<!^?^7_7N^J?T#`)'S4P&ILP``T/0#`*ISTD?Y8`)`N>WX_Y<"X`>1X0,4
MJ@``@%(M^?^7P```-```@%+S4T&I_7O"J,`#7]8?(`/58`)`N>'X_Y<`"$*Y
M``P4$A\00''@``!48`)`N=OX_Y<`"$*Y``P4$A\H0'$!_O]4X`,4JD$`@%+T
M^/^7'P``<>`7GQKS4T&I_7O"J,`#7];_!T#1`@``T/]#`-']>[RI_0,`D?-3
M`:FS``#0]5L"J;0C`9'W&P#Y]@,`JF/>1_E`8!*1]P,!JN$#%*ID`$#YI"<(
M^00`@-+B_X'28_C_EQ\``'%-!`!4`@0`4:'#/M%5?$"3(0`5BR'@?SEA`P`T
M%7Q`D^(#%:K@`Q2JX06`4AKY_Y?``@"TH```T`#01_D``$"YJ?C_E^,#%:KB
M`Q2JX0,6JAGY_Y=SWD?YH2=(^6`"0/D@``#*(`(`M?-30:GU6T*I]QM`^?U[
MQ*C_!T"1_T,`D<`#7];B_/\UH```T`#01_D``$"YE/C_E^(#%ZKA`Q:J<?C_
ME^S__Q>;^/^7H```T/U[OZG]`P"1`-!'^0``0+F)^/^7H@``T`,``-`!``#0
M8V`1D?U[P:@AH!*10LQ'^<'X_Q?]>[ZI_0,`D?,+`/FS``#0<])'^6`"0+EZ
M^/^7Z___EV`"0+EW^/^7\PM`^00``-`"``"PA"`@D0$``-#]>\*HXP,$JD(@
M/I$A(!.1!0"`4LCX_Q<?(`/5_PM`T?^#`-']>[VI_0,`D?5;`JFU``#0\U,!
MJ;/C`)&@WD?Y`0!`^:$G$/D!`(#2+OC_E^0#`"H%``#0`P``T*6`$Y%CH!.1
MX`,3JB(`@M(A`(!2\??_EP`$^#<`"(+2`@""TK8#`(O@`Q.JX0,6JO;W_Y?S
M`P"J``/X-P`$`!$`?$"3'?C_E_0#`*I@`@"T<WY`D^$#%JKB`Q.JS_?_EY]J
M,SC@`Q2JM=Y'^:(G4/FA`D#Y00`!RD$!`+7S4T&I]5M"J?U[PZC_"T"1_X,`
MD<`#7]8?(`/5``"`TO/__Q<^^/^7'R`#U<;__Q<?(`/5_P=`T0(``-#_0P#1
M_7NZJ?T#`)'U6P*IM@``T/-3`:GT`P"J]V,#J4``%)'Y:P2I\P,!JOLK`/FA
MDP&1PMY'^4,`0/FC-PCY`P"`TM?]_Y?U`P"JX`,4JN$%@%)W^/^7@`(`M```
M`-#A`Q2J`$`4D33^_Y?@`Q2JUMY'^:(W2/G!`D#Y00`!RD$+`+7S4T&I]5M"
MJ?=C0ZGY:T2I^RM`^?U[QJC_!T"1_T,`D<`#7];@`Q2J&```T)CW_Y?Y`P`J
M`8,4D>`#$ZJ0]_^7\P,`JJ#\_[07``#0&@``T/?B$Y$Y!P`16J,4D6`"0#D?
M``!Q<Q*7FK4``+3A`Q.JX`,5JAKX_Y=`!0`TX`,3JH/W_Y?A`P`J8,(@BP#P
M7S@?O`!QX0``5"$$`%%@PB&+?\HA.`#P7S@?O`!Q8/__5"$#`0L__#]Q#/G_
M5+NC`9$#``#0Y`,3JN8#%*KE`QJJ8\`4D>`#&ZJS``#0`@""TB$`@%)N]_^7
M<])'^6`"0+G/]_^7`N`'D>$#&ZH``(!2;_?_E^```#5@`D"YR/?_EP`(0KD`
M#!02'R!`<>```%0!@Q21``"`TE7W_Y?S`P"J8/G_M:G__Q?@`QNJ(0"`4MOW
M_Y?@_O\U````L.$#&ZH`0!21V/W_E^`#&ZIT]_^7H___%[[W_Y<?(`/5`0!`
M.<$``#0"!`"1/[P`<0`0@II!%$`XH?__-<`#7];]>[ZI_0,`D?-3`:E@`P"T
M%`!`.?,#`*H4`P`T.??_EP`$`-%B`@"+?P("ZV($`%1@:F`X'[P`<:```%0<
M```40`!`.1^\`'$A`P!40@0`T7\"`NMA__]4G[X`<>```%3S4T&I````L/U[
MPJ@`H!213/?_%Q\@`]5``(#27??_ET`%`+0"``"P0N`3D4(`0'D"``!Y\U-!
MJ?U[PJC``U_60`!`.1^\`'&``0!40@0`T7\"`NMC__]4?P("Z^#\_U1"!`#1
M?P("Z^(``%1``$`Y'[P`<8$``%1"!`#1?P("ZV/__U1"`!/+0`@`D1\$0/'(
M`0!4H```T.$#$ZH```.10@0`D1,@`)$#`(+2X`,3JCSW_Y?@`Q.J\U-!J?U[
MPJC``U_6'R`#U0``@-+S4T&I_7O"J,`#7];]>[BI`0``L"%@$9$```"P_0,`
MD?-3`:FS``"P]5L"J0#@%)'W8P.I%@``L&/>1_D7``"P)AQ!J6(`0/FB/P#Y
M`@"`TB040JFF'P6I(6!`>1@``+"D%P:I%```L*'C`'F48A:1M3,!D3C]_Y<`
M``"P`"`5D37]_Y<```"P`$`5D3+]_Y<```"P`(`5D2_]_Y?`HA61+?W_EP``
M`+``X!61*OW_E^`"%)$H_?^7`",6D2;]_Y?@`Q2J)/W_EP```+``H!:1(?W_
MEP```+``0!21'OW_EP```+``X!:1&_W_EP```+``(!>1&/W_EP```+#A`Q6J
M`&`7D=C\_Y>```"TX0,`JN`#%*HZ_?^7````L.$#%:H`P!>1T/S_EZ```+0"
M``"PX0,`JD`@&)$Q_?^7````L.$#%:H`8!B1Q_S_ET`"`+3A`P"JX`(4D2G]
M_Y<!``"PP*(5D2%`&9$E_?^7<]Y'^:$_0/E@`D#Y(```RF`#`+7S4T&I]5M"
MJ?=C0ZG]>\BHP`-?U@```+#A`Q6J`*`8D;'\_Y?```"TX0,`J@`C%I$3_?^7
MZO__%Q\@`]4!``"PH(<!D2$`&9%"`8#2M$,!D<WV_Y=`_/\U@6X`D0`C%I$'
M_?^7WO__%^_V_Y?]>[VI_0,`D?-3`:FS``"PM```T&'>1_F`$D"Y(@!`^:(7
M`/D"`(#2'P0`,2`!`%1SWD?YHA=`^6$"0/E!``'*H0(`M?-30:G]>\.HP`-?
MU@```+"ADP"1`"`6D8?\_Y=``0"T`0!`.3_``''B!Y\:/P``<>`'GQI````*
M@!(`N>S__Q<?(`/5``"`4H`2`+GH__\7R?;_E_U[OZG]`P"1:O;_E^GV_Y>`
M``"T``!`^?U[P:C``U_6``"`TOW__Q?]>[6IH0``T"%``)']`P"1]V,#J;@`
M`+#U6P*I]@,`JB`@`)'S4P&I^6L$J07?1_G[*P#Y`@Q!J08<0JFB#PBI!`1`
M^0@80/F@`$#YH%<`^0``@-(A!$#YIA\)J:$3!ZFH4P#Y00,`M/,#`:H```"P
M`0``L+7C`9&WLP&1.H`4D1G`%)$&```4X0,6J@OW_Y>``P"TLX9`^+,!`+3A
M`Q>JX`,3JD7\_Y?T`P"J8```M`$`0#FA_O\UX`,3JN$#%JJD_/^7LX9`^+/^
M_[48WT?YH5=`^0`#0/D@``#*H`,`M?-30:GU6T*I]V-#J?EK1*G[*T#Y_7O+
MJ,`#7]8?(`/5X`,6J@GV_Y?[`P"JX`,4J@;V_Y=@`P"+``@`D3_V_Y?[`P"J
MY@,4JN4#&JKD`Q:JXP,9J@(`@)(A`(!2__7_E^$#&ZK@`Q.J@OS_E]+__Q=J
M]O^7'R`#U?\C0-&A``#0_X,%T2%``)$B8`&1(R`"D?U[NJG]`P"1]V,#J;@`
M`+`D%$2I\U,!J?5;`JGV`P"J^6L$J;0#`Y'[<P6ILZ,"D2`H0/FU,P*1I!<)
MJ04WD-($WT?YH0,%BZ!3`/D:``"PA0!`^24``/D%`(#2_T,`T4`$0*F`!@"I
M0`1!J8`&`:GA`Q6J8`A`^4040JE@"@#Y8@Q`J4`#%)&$%@*I8@X`J>[[_Y>`
M``"T`0!`.?<#`*I!(@`U<?__EQ<`@-+Y`P"J`!``M.`#&:K`]?^7`/A_TP`$
M`)'Y]?^7&P``L"0#0#GW`P"J\P,`JGN#&9$D`0`TX`,3JN,#&ZH"`("2(0"`
M4G,*`)&U]?^7)!]`."3__S6@8T#YE"(`D8```+4/```4@(9`^*`!`+3A`Q6J
MR_O_E_,#`*I@__^T`0!`.2'__S06_?^7X/[_-.`#$ZK']?^7\P,`JN`"`+6S
M2T#Y<PP`M&`"0#DT`(!28`$`-5\``!0".)#2H`,"BP#,-(L`)$#1$VA'^3,+
M`+1@`D`YE`8`$<`*`#3@`Q.J`/W_EZ#^_S3@`Q.JL?7_E_,#`*H@_O^TX`,3
MJH7U_Y?T`P"JX`,7JH+U_Y<``!0+&Q`0$7M_0)/@`QNJN?7_E_0#`*H!``"P
M!@``L`,``+`EH!21YP,7JL:@&9'D`Q.J8\`9D0(`@)(A`(!2=?7_E^`#%*H!
M.(!27O;_EQ\$`#'`!@!4LP``L'/21_E@`D"YT/7_EP+@!Y'A`Q2J``"`4A#V
M_Y>@!P`TH```L`(``+##`D#YY`,4JD(@')$A`(!2`,A'^0``0/GJ]?^7``"`
MTAC?1_D!-Y#2H0,!BR(`0/D!`T#Y00`!RD$Y`+6_`P"1\U-!J?5;0JGW8T.I
M^6M$J?MS1:G]>\:H_R-`D?^#!9'``U_6'R`#U6[U_Y?Y`P"J8/#_M?<B`)'@
M:G/X(!(`M.$#%:IC^_^78/__M`$`0#G!_O\U]R(`D?C__Q<?(`/5$P"`TK'_
M_Q<>]O^7!0!`N;]$`'$`^?]4H```L`(``+##`D#YY`,4JD(`&I$A`(!2`,A'
M^0``0/FZ]?^7``"`TM#__Q<?(`/58`)`N8WU_Y<`"$*Y``P4$A\00''A]_]4
M8`)`N8?U_Y<7$$*Y-?7_E_\"`&LA]_]48`)`N8'U_Y<`"$*Y`"``$A\`!W%A
M]O]4X`,;JD_U_Y?S`P"J````L.$#%:H``"*1,OO_ER`,`+35`D#Y,_7_E^$#
M`*K@`Q6J0OW_E_4#`*I`"P"TX`,5J@3U_Y<?#`!Q]P,`JNT!`%0`?$"3`0``
ML``0`-$A`!N1H`(`BX_U_Y<``0`U_Q(`<0`F`%3@$@!1H,(@BP#P7S@?O`!Q
M8"4`5'C^_Y?````UX`,5J@$`@%+&]?^7H'\`N4`(`#4!``"P````L"%`&9$`
M(!:1`@``L!8``+!9H!21%0"`4FW[_Y?6PAN1&?7_E^8#`"H'``"P`P``L.<@
M()'E`QFJ8X`;D>0#%*K@`Q.J`@"`DB$`@%+W`P>JV?3_EQ(``!0?(`/5NO7_
MEP``0+D?1`!Q00(`5`;U_Y>U!@`1Y@,`*N<#%2KE`QFJY`,4JN,#%JK@`Q.J
M`@"`DB$`@%+W`P#YQ_3_E^`#$ZH!.(!2L/7_EQ\$`#&`_?]4X`,4JFSU_Y?A
M`Q.J0`,4D4/[_Y?@`Q.J;?[_E^`#$ZI=__\7:O[_E^`#%ZK:]/^76?__%QD`
M`+"@`8#2.6,9D?#^_Q?5`D#YIO__%T(`@%(A`H"2N^,&D0?U_Y>@?T"YX0,;
MJL(`@-)S]?^7H.-&.8```#6@YT8Y'PP!<8`>`%2@?T"Y`@"`4@$`@-*WPP.1
MO*,$D?CT_Y>__Q&I(6"$TB!QE=*AZ*SRH/F]\L*?F]*_:P&YH0,/J<&.BM(`
M/IS200:B\D!ZN/)"%[/RH8,0J>#B`)&B@P#YH#L`^:!_0+GA`QNJ`@"0TE/U
M_Y<?``!QXP,`JO8#`"K-"`!4HH]`^6!\0)-!#``+7P`!ZZ*30/E)``!40@0`
MD4!T0(NA@Q&IH&M!N4`5`#0!"(!2HS<`^38``$NA.T#Y?P`6:W;0EAH@P""+
MX0,;JM5^0)/B`Q6J7?3_EZ!K0;FC-T#YP`(`"Q\``7&@:P&YH?O_5.`#%ZIV
M`!9+>0,5BRWV_Y??_@!Q;10`5-8"`5'`?@93%61ZT[4"`9&@:P"Y-0,5BR8?
M0*G@`Q>J)!=!J88?`*DB#T*IA!<!J2@G0ZF"#P*IB"<#J3D#`9$:]O^7OP(9
MZX'^_U2@:T"YUAH`2Z`[0/G"?D"3X0,5J@,)@-)W]/^7MFL!N:!_0+GA`QNJ
M`@"0T@[U_Y<?``!QXP,`JO8#`"J,]_]4H']`N;#T_Y>VUU&IH@,YT<$B0],@
M!``10<`AB^(/@!(?X`!Q(J`].>P.`%0"!X!2X>(`D4(``$L@P""+`0"`4D)\
M0)-\]/^7H?Y0TZ+^6-/@`Q>JM8\%.:&'!3G!_EC3M?Y(TZ*#!3FADP4YPOY0
MT\'^2-.UBP4YHI<%.;DC!I&VGP4Y&P``L*&;!3GD]?^7I0]/J?P#&:JESP4Y
MML<%D:('4*FD?%C3IOQ0TZ7\2-.CWP4Y-Z,`D:7+!3EE_%C3HN\%.76#&9&E
MTP4Y9?Q0TV/\2-.@BT#YH?\%.:/;!3E#_%C3H`\&.:/C!3E#_%#30OQ(TZ3#
M!3FFQP4YHNL%.2+\6-.EUP4YHO,%.2+\4-,A_$C3H^<%.:+W!3D"_%C3H?L%
M.0'\4-,`_$C3H@,&.:$'!CF@"P8Y`@``%,060#C@`QRJXP,5J@(`@)(A`(!2
MG`L`D>CS_Y?_`ASK`?__5````+`'``"P`P``L`6@%)'G(""1Y@,9JN0#%*IC
M0!N1X`,3J@(`@)(A`(!2O\,&.=GS_Y?@`Q2J@_3_E^$#$ZI``Q216OK_E^`#
M$ZJ$_?^7X`,3JG3^_Q<?(`/5^0,;JFO__Q?6!D#YMMK_M.`#%JK%\_^7'PP`
M\2G:_U0`$`#1`0``L"$@&Y'``@"+4O3_EQ\``'&U$I::R?[_%_4#&:IR__\7
M`@B`4OOB`)%"``!+`0"`4F##((M"?$"3!O3_E^`#%ZI^]?^7?W\`J7]_`:E_
M?P*I_S8`^83__Q>@ZT8Y'P0!<6'A_U2@[T8Y'PP!<0'A_U2@\T8Y'R`!<:'@
M_U2@]T8Y'Q0!<4'@_U2U?T"Y0@"`4B$'@)+@`Q4J^O/_E^$#&ZK@`Q4J(@6`
MTF;T_Y<```"P!P``L`,``+`%H!21YR`@D>8#&ZKD`Q2J8T`;D>`#$ZH"`("2
M(0"`4H[S_Y?,_O\7_//_EQ\@`]7]>[BIH0``L/T#`)'W8P.IN```L*#3`9'S
M4P&IH#<`^?,#`*H`TT?Y]5L"J?EK!*G[<P6I(=Q'^0``0+DB`$#YHC\`^0(`
M@-+<\_^7(P"`4@(``+#A`Q.J`\0".4"@%9&2^?^7@```M`$`0#D_Q`!Q`!,`
M5'?\_Y<6TT?YNP``T,`"0+G-\_^7`0``D&,!@%(A@!V1(@"`4MSS_Y>`!@"T
M=0,'D0$(0/F@@E"X-Q1`^1\$`''-!0!4&8"`4A0`@%(S`(!2&02@<@L``!0?
M(`/500A`^>`#&JKD\_^7X`,`-:""4+AS!@`1E`8`$1\`$VN-`P!4P`)`N;#S
M_Y>"?D"3X0,7J@,`@%(0]/^7_`,`JD`"`+0"`$#YHP)1^$`,0+EZV'/X```9
M"A\`$'$@_?]4P`)`N:'S_Y>!`T#Y0P"`4@(`@-*-\_^7X0,`JN`#&JK&\_^7
M8/S_-&`#!Y$`@%"X`00`43\`%&O`"P!4%--'^8`"0+F1\_^7`0``D&,`@%(A
MH!V1(@"`4J#S_Y?S`P"J@`$`M(`"0+F(\_^780I`^0(``)!"P!V1(0!`^6/S
M_Y=@"D#Y``!`^0`,0+G@#+`W%--'^8`"0+E\\_^7`0``D&,`@%(AX!V1(@"`
M4HOS_Y?S`P"JH`$`M````)"A-T#Y`$`4D2WY_Y?U`P"J@`)`N=4)`+1M\_^7
M80I`^>(#%:HA`$#Y2?/_EQC31_ET`P>1``-`N67S_Y?S`P"J``-`N6+S_Y<!
M``"0(@"`4B$`'I&6\_^7X0,`J@(``)#@`Q.J0F`>D3GS_Y<``T"Y5_/_EQ_$
M`CD"``"0H3=`^4``%)$.^?^7@((1^/,#`*K@!`"TX`,3J@$X@%+4\_^7`00`
M$3\$`'$$B%%ZX08`5*```)`:W$?YH3]`^4`#0/D@``#*``8`M?-30:GU6T*I
M]V-#J?EK1*G[<T6I_7O(J,`#7]8`!$`Y(.W_-&?__Q<?(`/5'P0`<4WT_U05
MTT?Y=`,'D3,`@%*@`D"Y<P8`$2_S_Y?A`Q>JY?+_EX""4+@?`!-K+/__5);_
M_Q>``E'XR_S_EX""$?CS`P"JP/K_M0```)``@!Z17?/_ER#S_Y=@`P>18@I`
M^0$`4?A``$#Y(0!`^4SZ_Y>Q__\7@`)`N1?S_Y=A"D#Y(0!`^6CS_Y>5__\7
M'O/_EWL#!Y$!``"0XP,`*B`@'Y'B`Q.J80-1^"$`0/E&\_^7'R`#U?U[OJG]
M`P"1\U,!J?0#`*I<^_^7\P,`J@``0#G````T808`D1^\`'%S$H&:(!1`.*#_
M_S49_/^7GP(`\0080'H@`0!4@`)`.>```#0!``"0X`,3JB&@&9%N\_^7?P(`
MZX```%3S4T&I_7O"J,`#7];@`Q2J\U-!J?U[PJB9^?\7HP``D&/@1_F#``"T
M8P!`^:#R_Q<?(`/5`P"`TIWR_Q?]>[RI_0,`D?5;`JFU``"0\U,!J;0``)"U
M@BR1E*(LD90"%<OW8P.I]@,"JO@#`"KW`P&J4?+_EY3^0Y-4`0"T$P"`TJ-Z
M<_CB`Q:JX0,7JN`#&"IS!@"18``_UG\"%.LA__]4\U-!J?5;0JGW8T.I_7O$
MJ,`#7];``U_6_7N_J?T#`)']>\&HP`-?U@`````!``(``````'!E<FQX<VDN
M8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````
M````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$
M>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4`````
M`"]P<F]C+R5I+R5S```````N`````````%!!4E]414U0``````````!005)?
M4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``4$523#5,24(`
M`````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.
M251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````4$%2
M7T1%0E5'`````````%!!4E]#04-(10````````!005)?05)'0P``````````
M4$%27T%21U9?,````````%!!4E]'3$]"04Q?1$5"54<``````````%!!4E]'
M3$]"04Q?5$U01$E2`````````%!!4E]435!$25(```````!005)?1TQ/0D%,
M7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````4$%27T-,14%./0``````
M`#$`````````4UE35$5-```E,#)X`````'!A<BT`````)7,E<R5S)7,`````
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H```````!P87)L`````"YP87(`````)7,E<V-A
M8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S````
M```````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````
M````05)'5@`````8`````````'!E<FP`````,`````````!005(Z.E!A8VME
M<CHZ5D524TE/3@`````Q+C`S-0```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@
M9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M
M90```````"TM````````55-%4@````!54T523D%-10``````````5$U01$E2
M``!414U01$E2`%1%35``````5$U0```````O=&UP`````$Q$7TQ)0E)!4EE?
M4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%4
M2`````````!32$Q)0E]0051(````````979A;"`G97AE8R`O=7-R+V)I;B]P
M97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP
M+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I
M;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E
M<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M
M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-
M4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@
M,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H
M;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE
M;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T
M96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@
M=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@
M?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F
M26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D[
M"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'
M5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@
M+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!]
M.PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@
M:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@
M+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI
M;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL
M"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T
M87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I
M;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64[
M"FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*
M)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L
M("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N
M86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E
M=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL
M97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<
M;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@
M)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*
M?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0[
M"G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E
M96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D
M(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY
M("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F
M:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]
M?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S
M96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\
M*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN
M*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D;W5T+"`D9FEL96YA;64I(#T@
M7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O
M=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["F-H;6]D(#`W-34L
M("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO
M/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F
M:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*;W5T
M<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P96X@;7D@)&]U="P@)SXG+"`D
M9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T
M("1B=68["F-L;W-E("1O=70["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN
M86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C
M:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U
M;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[
M)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH
M)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O=70L("1N
M86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["FEF
M("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&9I;&5N86UE
M+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D;F%M
M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN
M(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER
M92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]
M"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@
M)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!
M4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U
M<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)5
M1WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L
M:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS
M("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%2
M7T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@
M<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@
M>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H
M)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2![
M"B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N
M9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q
M.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R
M(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S
M:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F
M:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2([
M"F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I
M92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2
M+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*
M9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@
M(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W
M+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D
M871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P
M.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O
M<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*
M;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM
M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R
M(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE
M;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!0
M05(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN
M:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![
M("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D
M7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S
M.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J
M96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N
M9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES
M("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER
M("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%
M7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I
M.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:
M(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L
M<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO
M:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO
M<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE
M.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S
M92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA
M;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*
M?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&
M24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H
M)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I
M9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O
M=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H
M85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\
M(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO
M;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D
M8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O
M=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I
M9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@
M;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<
M;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X
M:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?
M<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O
M<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S
M*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER
M92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N
M>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R
M;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?
M<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*
M<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H
M($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P
M871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*
M;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D
M969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@
M*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92![
M"B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I
M<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!
M4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=
M*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@
M+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@
M(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D
M8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA
M9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM
M;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X
M(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*
M?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T
M;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D97AT+"`D8W)C*2`]
M($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL96YA;64@/2`B)'!A<E]T
M96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PIU;FQI;FL@
M)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL92P@)&9I
M;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF
M("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O
M<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I;&5N86UE
M*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!
M4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%2
M7R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y6
M7U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%
M35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES
M=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S
M='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!
M4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO
M.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H
M*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN
M(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)
M3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W
M*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X
M<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I
M;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R
M.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG
M="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@
M;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G
M;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@
M)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2
M.PHQ.PI?7T5.1%]?"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``$``````````0`````````!`````````-`!`````````0`````````?`@``
M``````$`````````>@,````````,`````````#@=````````#0`````````\
M5````````!D`````````()L!```````;``````````@`````````&@``````
M```HFP$``````!P`````````"`````````#U_O]O`````&`"````````!0``
M``````"@#0````````8`````````4`,````````*`````````/D$````````
M"P`````````8`````````!4````````````````````#`````````%B=`0``
M`````@``````````!@```````!0`````````!P`````````7`````````#@7
M````````!P````````#8$P````````@`````````8`,````````)````````
M`!@`````````&````````````````````/O__V\``````0``"`````#^__]O
M`````'@3````````____;P`````#`````````/#__V\`````FA(```````#Y
M__]O`````!<`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!0'0```````%`=````````
M4!T```````!0'0```````%`=````````4!T```````!0'0```````%`=````
M````4!T```````!0'0```````%`=````````4!T```````!0'0```````%`=
M````````4!T```````!0'0```````%`=````````4!T```````!0'0``````
M`%`=````````4!T```````!0'0```````%`=````````4!T```````!0'0``
M`````%`=````````4!T```````!0'0```````%`=````````4!T```````!0
M'0```````%`=````````4!T```````!0'0```````%`=````````4!T`````
M``!0'0```````%`=````````4!T```````!0'0```````%`=````````4!T`
M``````!0'0```````%`=````````4!T```````!0'0```````%`=````````
M4!T```````!0'0```````%`=````````4!T```````!0'0```````%`=````
M````4!T```````!0'0```````%`=````````4!T```````!0'0```````%`=
M````````4!T```````!0'0```````%`=````````4!T```````!0'0``````
M`#B;`0``````.%0`````````````````````````````````````````````
M````````````````````````````````````````````````"*`!``````#`
M4P``````````````````<"$`````````````````````````````````````
M``````````````````````````````````#_____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'0T,Z("A58G5N='4O3&EN87)O(#4N-"XP+39U8G5N
M='4Q*2`U+C0N,"`R,#$V,#8P.0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN
M`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M
M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`
M+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````````
M``````````````````````````````````````````````````````````L`
M```!`````@```````````@`````````"````````&P``````````````````
M``$````````````````````3````!P````(`````````'`(````````<`@``
M`````"`````````````````````$````````````````````(0````<````"
M`````````#P"````````/`(````````D````````````````````!```````
M`````````````#0```#V__]O`@````````!@`@```````&`"````````[```
M```````%``````````@````````````````````^````"P````(`````````
M4`,```````!0`P```````%`*````````!@````,````(`````````!@`````
M````1@````,````"`````````*`-````````H`T```````#Y!```````````
M`````````0```````````````````$X```#___]O`@````````":$@``````
M`)H2````````W``````````%``````````(``````````@````````!;````
M_O__;P(`````````>!,```````!X$P```````&``````````!@````,````(
M````````````````````:@````0````"`````````-@3````````V!,`````
M``!@`P````````4`````````"``````````8`````````'0````$````0@``
M```````X%P```````#@7``````````8````````%````%0````@`````````
M&`````````!^`````0````8`````````.!T````````X'0```````!0`````
M```````````````$````````````````````>0````$````&`````````%`=
M````````4!T````````@!```````````````````$``````````0````````
M`(0````!````!@````````!P(0```````'`A````````S#(`````````````
M``````@```````````````````"*`````0````8`````````/%0````````\
M5````````!`````````````````````$````````````````````D`````$`
M```"`````````%!4````````4%0```````#@00``````````````````"```
M`````````````````)@````!`````@`````````PE@```````#"6````````
M!`````````````````````0```````````````````"B````#@````,`````
M````()L!```````@FP````````@````````````````````(````````````
M````````K@````\````#`````````"B;`0``````*)L````````(````````
M````````````"````````````````````+H````!`````P`````````PFP$`
M`````#";````````"`````````````````````@```````````````````"_
M````!@````,`````````.)L!```````XFP```````"`"````````!@``````
M```(`````````!``````````R`````$````#`````````%B=`0``````6)T`
M``````"H`@``````````````````"``````````(`````````,T````!````
M`P``````````H`$```````"@````````N`````````````````````@`````
M``````````````#3````"`````,`````````N*`!``````"XH````````#`0
M```````````````````(````````````````````V`````$````P````````
M````````````N*`````````S`````````````````````0`````````!````
M``````$````#`````````````````````````.N@````````X0``````````
7``````````$`````````````````````
